@@ -1,5 +1,6 @@
 import os
 import boto3
+import utils
 import logging
 import botocore
 import tempfile
@@ -105,7 +106,7 @@ def s3_download(bucket, key):
     c = s.resource("s3")
     logger.info("boto3 s3 client created")
 
-    temp_file = tempfile.NamedTemporaryFile()
+    temp_file = tempfile.NamedTemporaryFile(suffix=utils.get_file_extension(key))
     local_path = temp_file.name
 
     try:
